@@ -1,21 +1,25 @@
-/* Evolution calendar - Generic view factory for calendar views
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * Author: Federico Mena-Quintero <federico@ximian.com>
+/*
+ * Evolution calendar - Generic view factory for calendar views
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Federico Mena-Quintero <federico@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,11 +41,15 @@ struct _CalendarViewFactoryPrivate {
 
 
 
-static void calendar_view_factory_finalize (GObject *object);
-
-static const char *calendar_view_factory_get_title (GalViewFactory *factory);
-static const char *calendar_view_factory_get_type_code (GalViewFactory *factory);
-static GalView *calendar_view_factory_new_view (GalViewFactory *factory, const char *name);
+static void	calendar_view_factory_finalize	(GObject *object);
+static const gchar *
+		calendar_view_factory_get_title	(GalViewFactory *factory);
+static const gchar *
+		calendar_view_factory_get_type_code
+						(GalViewFactory *factory);
+static GalView *
+		calendar_view_factory_new_view	(GalViewFactory *factory,
+						 const gchar *name);
 
 G_DEFINE_TYPE (CalendarViewFactory, calendar_view_factory, GAL_VIEW_FACTORY_TYPE)
 
@@ -95,7 +103,7 @@ calendar_view_factory_finalize (GObject *object)
 
 
 /* get_title method for the calendar view factory */
-static const char *
+static const gchar *
 calendar_view_factory_get_title (GalViewFactory *factory)
 {
 	CalendarViewFactory *cal_view_factory;
@@ -123,7 +131,7 @@ calendar_view_factory_get_title (GalViewFactory *factory)
 }
 
 /* get_type_code method for the calendar view factory */
-static const char *
+static const gchar *
 calendar_view_factory_get_type_code (GalViewFactory *factory)
 {
 	CalendarViewFactory *cal_view_factory;
@@ -152,7 +160,7 @@ calendar_view_factory_get_type_code (GalViewFactory *factory)
 
 /* new_view method for the calendar view factory */
 static GalView *
-calendar_view_factory_new_view (GalViewFactory *factory, const char *name)
+calendar_view_factory_new_view (GalViewFactory *factory, const gchar *name)
 {
 	CalendarViewFactory *cal_view_factory;
 	CalendarViewFactoryPrivate *priv;
@@ -177,7 +185,7 @@ calendar_view_factory_new_view (GalViewFactory *factory, const char *name)
  *
  * Return value: The same value as @cal_view_factory.
  **/
-CalendarViewFactory *
+GalViewFactory *
 calendar_view_factory_construct (CalendarViewFactory *cal_view_factory,
 				 GnomeCalendarViewType view_type)
 {
@@ -190,7 +198,7 @@ calendar_view_factory_construct (CalendarViewFactory *cal_view_factory,
 
 	priv->view_type = view_type;
 
-	return cal_view_factory;
+	return GAL_VIEW_FACTORY (cal_view_factory);
 }
 
 /**
@@ -201,7 +209,7 @@ calendar_view_factory_construct (CalendarViewFactory *cal_view_factory,
  *
  * Return value: A newly-created calendar view factory.
  **/
-CalendarViewFactory *
+GalViewFactory *
 calendar_view_factory_new (GnomeCalendarViewType view_type)
 {
 	CalendarViewFactory *cal_view_factory;
