@@ -632,12 +632,16 @@ comp_subject (ECalComponentItipMethod method, ECalComponent *comp)
 		switch (e_cal_component_get_vtype (comp)) {
 		case E_CAL_COMPONENT_EVENT:
 			description = _("Event information");
+			break;
 		case E_CAL_COMPONENT_TODO:
 			description = _("Task information");
+			break;
 		case E_CAL_COMPONENT_JOURNAL:
 			description = _("Memo information");
+			break;
 		case E_CAL_COMPONENT_FREEBUSY:
 			description = _("Free/Busy information");
+			break;
 		default:
 			description = _("Calendar information");
 		}
@@ -896,7 +900,6 @@ comp_limit_attendees (ECalComponent *comp)
 
 		if (!match)
 			list = g_slist_prepend (list, prop);
-		match = FALSE;
 	}
 
 	for (l = list; l != NULL; l = l->next) {
@@ -1205,8 +1208,37 @@ append_cal_attachments (EMsgComposer *composer,
 	g_slist_free (attach_list);
 }
 
+static EAccount *
+find_enabled_account (EAccountList *accounts, const gchar *id_address)
+{
+	EIterator *it;
+	EAccount *account = NULL;
+
+	g_return_val_if_fail (accounts != NULL, NULL);
+
+	if (!id_address)
+		return NULL;
+
+	for (it = e_list_get_iterator ((EList *)accounts);
+	     e_iterator_is_valid (it);
+	     e_iterator_next (it)) {
+		account = (EAccount *)e_iterator_get (it);
+
+		if (account
+		    && account->enabled
+		    && account->id
+		    && account->id->address
+		    && g_ascii_strcasecmp (account->id->address, id_address) == 0)
+			break;
+
+		account = NULL;
+	}
+
+	return account;
+}
+
 static void
-setup_from (ECalComponentItipMethod method, ECalComponent *comp, EComposerHeaderTable *table)
+setup_from (ECalComponentItipMethod method, ECalComponent *comp, ECal *client, EComposerHeaderTable *table)
 {
 	EAccountList *accounts;
 
@@ -1214,11 +1246,21 @@ setup_from (ECalComponentItipMethod method, ECalComponent *comp, EComposerHeader
 	if (accounts) {
 		EAccount *account = NULL;
 
+		/* always use organizer's email when user is an organizer */
+		if (itip_organizer_is_user (comp, client)) {
+			ECalComponentOrganizer organizer = {0};
+
+			e_cal_component_get_organizer (comp, &organizer);
+			if (organizer.value != NULL) {
+				account = find_enabled_account (accounts, itip_strip_mailto (organizer.value));
+			}
+		}
+
 		if (!account) {
 			gchar *from = comp_from (method, comp);
 
 			if (from)
-				account = (EAccount *) e_account_list_find (accounts, E_ACCOUNT_FIND_ID_ADDRESS, from);
+				account = find_enabled_account (accounts, from);
 
 			g_free (from);
 		}
@@ -1284,7 +1326,7 @@ itip_send_comp (ECalComponentItipMethod method, ECalComponent *send_comp,
 	composer = e_msg_composer_new ();
 	table = e_msg_composer_get_header_table (composer);
 
-	setup_from (method, send_comp, table);
+	setup_from (method, send_comp, client, table);
 	e_composer_header_table_set_subject (table, subject);
 	e_composer_header_table_set_destinations_to (table, destinations);
 
@@ -1386,7 +1428,7 @@ reply_to_calendar_comp (ECalComponentItipMethod method,
 	composer = e_msg_composer_new ();
 	table = e_msg_composer_get_header_table (composer);
 
-	setup_from (method, send_comp, table);
+	setup_from (method, send_comp, client, table);
 	e_composer_header_table_set_subject (table, subject);
 	e_composer_header_table_set_destinations_to (table, destinations);
 
@@ -1516,10 +1558,9 @@ itip_publish_begin (ECalComponent *pub_comp, ECal *client,
 
 	if (e_cal_component_get_vtype (pub_comp) == E_CAL_COMPONENT_FREEBUSY) {
 
-		if (!cloned) {
+		if (!cloned)
 			*clone = e_cal_component_clone (pub_comp);
-			cloned = TRUE;
-		} else {
+		else {
 
 			icomp = e_cal_component_get_icalcomponent (pub_comp);
 			icomp_clone = e_cal_component_get_icalcomponent (*clone);
