@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gal-view-factory-etable.c
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -31,7 +31,7 @@
 
 G_DEFINE_TYPE (GalViewFactoryEtable, gal_view_factory_etable, GAL_VIEW_FACTORY_TYPE)
 
-static const char *
+static const gchar *
 gal_view_factory_etable_get_title       (GalViewFactory *factory)
 {
 	return _("Table");
@@ -39,12 +39,12 @@ gal_view_factory_etable_get_title       (GalViewFactory *factory)
 
 static GalView *
 gal_view_factory_etable_new_view        (GalViewFactory *factory,
-					 const char     *name)
+					 const gchar     *name)
 {
 	return gal_view_etable_new(GAL_VIEW_FACTORY_ETABLE(factory)->spec, name);
 }
 
-static const char *
+static const gchar *
 gal_view_factory_etable_get_type_code (GalViewFactory *factory)
 {
 	return "etable";
@@ -94,7 +94,8 @@ gal_view_factory_etable_init            (GalViewFactoryEtable *factory)
 GalViewFactory *
 gal_view_factory_etable_new        (ETableSpecification  *spec)
 {
-	return gal_view_factory_etable_construct (g_object_new (GAL_VIEW_FACTORY_ETABLE_TYPE, NULL), spec);
+	return gal_view_factory_etable_construct (
+		g_object_new (GAL_VIEW_FACTORY_ETABLE_TYPE, NULL), spec);
 }
 
 /**
