@@ -258,7 +258,6 @@ e_calendar_style_set		(GtkWidget	*widget,
 				 GtkStyle	*previous_style)
 {
 	ECalendar *e_calendar;
-	GtkWidget *parent;
 
 	e_calendar = E_CALENDAR(widget);
 	if (GTK_WIDGET_CLASS (e_calendar_parent_class)->style_set)
@@ -267,8 +266,7 @@ e_calendar_style_set		(GtkWidget	*widget,
 
 	/* Set the background of the canvas window to the normal color,
 	   or the arrow buttons are not displayed properly. */
-	parent = gtk_widget_get_parent (widget);
-	if (GTK_WIDGET_REALIZED (parent)) {
+	if (GTK_WIDGET_REALIZED (widget)) {
 		GtkStyle *style;
 		GdkWindow *window;
 
@@ -308,6 +306,7 @@ e_calendar_size_allocate	(GtkWidget	*widget,
 {
 	ECalendar *cal;
 	GtkStyle *style;
+	GtkAllocation old_allocation;
 	PangoFontDescription *font_desc;
 	PangoContext *pango_context;
 	PangoFontMetrics *font_metrics;
@@ -330,8 +329,9 @@ e_calendar_size_allocate	(GtkWidget	*widget,
 	/* Set the scroll region to its allocated size, if changed. */
 	gnome_canvas_get_scroll_region (GNOME_CANVAS (cal),
 					NULL, NULL, &old_x2, &old_y2);
-	new_x2 = widget->allocation.width - 1;
-	new_y2 = widget->allocation.height - 1;
+	gtk_widget_get_allocation (widget, &old_allocation);
+	new_x2 = old_allocation.width - 1;
+	new_y2 = old_allocation.height - 1;
 	if (old_x2 != new_x2 || old_y2 != new_y2)
 		gnome_canvas_set_scroll_region (GNOME_CANVAS (cal),
 						0, 0, new_x2, new_y2);
